@@ -1,5 +1,6 @@
 from typing import Optional, Union, List
-from uuid import UUID
+
+from slapp_py.core_classes.simple_source import SimpleSource
 
 from slapp_py.core_classes.socials.social import Social
 
@@ -9,7 +10,7 @@ BATTLEFY_BASE_ADDRESS = "battlefy.com/teams"
 class BattlefyTeamSocial(Social):
     def __init__(self,
                  persistent_team_id: Optional[str] = None,
-                 sources: Union[None, UUID, List[UUID]] = None):
+                 sources: Union[None, SimpleSource, List[SimpleSource]] = None):
         super().__init__(
             value=persistent_team_id,
             sources=sources,
