@@ -1,6 +1,5 @@
 from typing import Optional, Union, List
-from uuid import UUID
-
+from slapp_py.core_classes.simple_source import SimpleSource
 from slapp_py.core_classes.socials.social import Social
 
 SENDOU_BASE_ADDRESS = "sendou.ink/u"
@@ -9,7 +8,7 @@ SENDOU_BASE_ADDRESS = "sendou.ink/u"
 class Sendou(Social):
     def __init__(self,
                  handle: Optional[str] = None,
-                 sources: Union[None, UUID, List[UUID]] = None):
+                 sources: Union[None, SimpleSource, List[SimpleSource]] = None):
         super().__init__(
             value=handle,
             sources=sources,
