@@ -150,3 +150,16 @@ def key_value_list_to_dict(kv_list: List[tuple]) -> Dict[Any, list]:
         # DefaultDict
         d.setdefault(k, []).append(v)
     return d
+
+
+def order_dict_by_value(dictionary: Mapping[T, U], reverse: bool = False) -> Dict[T, U]:
+    """
+    Orders a dictionary by its values. Reverse is passed to the sorted builtin.
+    If the value is a List, a min (reverse=False) or max (reverse=True) is performed on the values
+    and its result is used in the ordering.
+    """
+    return dict(sorted(dictionary.items(),
+                       key=lambda item:
+                           (max(item[1]) if reverse else min(item[1])) if isinstance(item[1], list)
+                           else item[1],
+                       reverse=reverse))
