@@ -63,6 +63,6 @@ if __name__ == '__main__':
     logging.basicConfig(level=logging.DEBUG)
     logging.getLogger().setLevel("DEBUG")
 
-    full_rebuild(skip_pauses=True, patch=False)
-    # update_sources_with_placements()
-    # update_sources_with_skills(clear_current_skills=True)
+    # full_rebuild(skip_pauses=True, patch=False)
+    update_sources_with_placements()
+    update_sources_with_skills(clear_current_skills=True)
