@@ -122,7 +122,8 @@ class SlappResponseObject:
         return self.get_teams_from_ids([team_id])[0]
 
     def get_teams_for_player(self, p: Player) -> List[Team]:
-        return [self.get_team(t_uuid) for t_uuid in p.teams_information.get_teams_unordered()]
+        """Gets the resolved teams for this player in most recent chronological order. First is the current team."""
+        return [self.get_team(t_uuid) for t_uuid in p.teams_information.get_teams_ordered()]
 
     def get_best_team_for_player(self, p: Player) -> Team:
         return self.get_best_team_by_div([self.get_team(t_uuid) for t_uuid in p.teams_information.get_teams_unordered()])
@@ -135,7 +136,8 @@ class SlappResponseObject:
         players = self.get_players_in_team(team_guid, include_ex_players)
         return {player: player.skill for player in players}
 
-    def get_grouped_sources(self, obj: Union[Player, Team]) -> Dict[str, List[SimpleSource]]:
+    @staticmethod
+    def get_grouped_sources(obj: Union[Player, Team]) -> Dict[str, List[SimpleSource]]:
         """Group the SimpleSource list for the specified sources/team/player by tourney name."""
         simple_sources = obj.sources
         result = {}
@@ -146,12 +148,13 @@ class SlappResponseObject:
             sources_for_tourney.sort(key=lambda s: s.name, reverse=True)
         return result
 
-    def get_grouped_sources_text(self, sources: Union[Player, Team, List[UUID]]) -> List[str]:
+    @staticmethod
+    def get_grouped_sources_text(sources: Union[Player, Team, List[UUID]]) -> List[str]:
         """
         Group the SimpleSource list for the specified sources/team/player by tourney name.
         Duplicates are removed.
         """
-        groups = self.get_grouped_sources(sources)
+        groups = SlappResponseObject.get_grouped_sources(sources)
         message = []
         for tourney, simple_sources in groups.items():
             group_key = tourney + ': ' if tourney else ''
